@@ -1,7 +1,7 @@
 package Chemistry::OpenSMILES;
 
 # ABSTRACT: OpenSMILES format reader and writer
-our $VERSION = '0.12.0'; # VERSION
+our $VERSION = '0.12.1'; # VERSION
 
 use strict;
 use warnings;
@@ -432,6 +432,16 @@ sub _validate($@)
     my $color_by_element = sub { $_[0]->{symbol} };
 
     for my $atom (sort { $a->{number} <=> $b->{number} } $moiety->vertices) {
+
+        # Warn about aromatic atoms with less than two aromatic bonds
+        if( is_aromatic($atom) && $moiety->degree($atom) &&
+            2 > grep { is_aromatic_bond( $moiety, $atom, $_ ) }
+                     $moiety->neighbours( $atom ) ) {
+            warn sprintf 'aromatic atom %s(%d) has less than 2 aromatic bonds' . "\n",
+                         $atom->{symbol},
+                         $atom->{number};
+        }
+
         if( is_chiral_allenal($atom) ) {
             if( $moiety->degree($atom) != 2 ) {
                 warn sprintf 'tetrahedral chiral allenal setting for %s(%d) ' .
@@ -590,6 +600,19 @@ sub _validate($@)
                              $B->{number};
             }
         }
+
+        # Warn about 2 aromatic atoms in a cycle not having an aromatic bond between them
+        if(  is_aromatic( $A ) &&
+             is_aromatic( $B ) &&
+            !is_aromatic_bond( $moiety, $A, $B ) &&
+             is_ring_bond( $moiety, $A, $B ) ) {
+            warn sprintf 'aromatic atoms %s(%d) and %s(%d) belong to same cycle, ' .
+                         'but the bond between them is not aromatic' . "\n",
+                         $A->{symbol},
+                         $A->{number},
+                         $B->{symbol},
+                         $B->{number};
+        }
     }
 
     # Check allene systems
